@@ -6,9 +6,7 @@ __all__ = (
 )
 
 
-def strip_language_from_path(
-        path: str
-) -> str:
+def strip_language_from_path(path: str) -> str:
     """
     Return current path from request, excluding language code
     """
@@ -16,10 +14,7 @@ def strip_language_from_path(
 
     if regex_match:
         lang_code = regex_match.group(1)
-        languages = [
-            language_tuple[0] for
-            language_tuple in settings.LANGUAGES
-        ]
+        languages = [language_tuple[0] for language_tuple in settings.LANGUAGES]
 
         if lang_code in languages:
             path = path[1 + len(lang_code):]
